==> magic3_1.7.18_src.tar.gz: magic3/templates/browns/index.php <==
<?php
/**
* @Template ... :  Browns:  
* @Version: 1.8
* @Package: A Joomla 1.0.X template
* @Copyright: (C) 2006 by Rami Ben-Ami - http://www.lady-beetle.com/
* @License: GPL
**/

defined( '_VALID_MOS' ) or die( 'Direct Access to this location is not allowed.' );
$iso = split( '=', _ISO ); echo '<?xml version="1.0" encoding="'. $iso[1] .'"?' .'>';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; <?php echo _ISO; ?>" />
<?php mosShowHead(); ?>

<!-- CSS Joomla code here -->
<link href="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/css/template_css.css";?>" rel="stylesheet" type="text/css" media="all" />
<link rel="shortcut icon" href="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/favicon.ico"; ?>" />

</head>
<?php if ( $my->id ) { initEditor(); } ?>
<body>


<table width="770" height="90" border="0" align="center" cellpadding="0" cellspacing="0" >
  <tr>
    <td valign="top" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>header.jpg"><table width="100%" border="0" cellpadding="10" cellspacing="0" >
        <tr>
          <td width="110">&nbsp;</td>
          <td>&nbsp;<font class="site_name"><?php echo $mosConfig_sitename; ?></font></td>
          <td align="right"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>logo.gif" alt="" /></td>
          <td width="10">&nbsp;</td>
        </tr>
    </table></td>
  </tr>
</table>
<table width="770" height="34" border="0" align="center" cellpadding="0" cellspacing="0" >
  <tr>
    <td width="488"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>header_02.jpg" width="488" height="34" alt="" /></td>
    <td align="right" valign="middle" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>head_06.jpg" bgcolor="#E0E0A0"><?php echo mosCurrentDate(); ?></td>
    <td width="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>head_08.jpg" width="9" height="34" alt="" /></td>
  </tr>
</table>
<table width="770" height="31" border="0" align="center" cellpadding="0" cellspacing="0" >
  <tr>
    <td width="131"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>header_09.jpg" width="131" height="31" alt="" /></td>
    <td bgcolor="#664301">&nbsp;<?php mosPathWay(); ?>
</td>
  </tr>
</table>
<table width="770" height="31" border="0" align="center" cellpadding="0" cellspacing="0" >
  <tr>
    <td width="162" valign="top"><table width="100%" height="100%" border="0" align="center" cellpadding="0" cellspacing="0" >
        <tr>
          <td width="13" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_13.jpg" width="13" height="22" alt="" /></td>
          <td height="22" align="right" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_14.jpg"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_15.jpg" width="142" height="22" alt="" /></td>
          <td width="4" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_16.jpg" width="4" height="22" alt="" /></td>
        </tr>
        <tr>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_24.jpg">&nbsp;</td>
          <td valign="top" bgcolor="#EAD9AE">&nbsp;<br />
              <?php if (mosCountModules('left')>0) mosLoadModules('left',0); ?>
          <?php if (mosCountModules('user1')>0) mosLoadModules('user1',0); ?></td>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_26.jpg">&nbsp;</td>
        </tr>
        <tr>
          <td width="13" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_35.jpg" width="13" height="9" alt="" /></td>
          <td height="9" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_36.jpg"></td>
          <td width="4" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_38.jpg" width="4" height="9" alt="" /></td>
        </tr>
    </table></td>
    <td width="5" bgcolor="#664301">&nbsp;</td>
    <td valign="top"><table width="100%" height="100%" border="0" align="center" cellpadding="0" cellspacing="0" >
        <tr>
          <td width="13" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_13.jpg" width="13" height="22" alt="" /></td>
          <td height="22" align="right" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_14.jpg">&nbsp;</td>
          <td width="4" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_16.jpg" width="4" height="22" alt="" /></td>
        </tr>
        <tr>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_24.jpg">&nbsp;</td>
          <td valign="top" bgcolor="#EAD9AE"><?php if (mosCountModules('user3')>0) mosLoadModules('user3',0); ?>
            <?php if (mosCountModules('top')>0) mosLoadModules('top',0); ?>
              <br />
              <hr />
          <?php mosMainBody(); ?>

</td>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_26.jpg">&nbsp;</td>
        </tr>
        <tr>
          <td width="13" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_35.jpg" width="13" height="9" alt="" /></td>
          <td height="9" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_36.jpg"></td>
          <td width="4" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_38.jpg" width="4" height="9" alt="" /></td>
        </tr>
    </table>
    </td>
    <td width="5" bgcolor="#664301">&nbsp;</td>
    <td width="162" valign="top"><table width="100%" height="100%" border="0" align="center" cellpadding="0" cellspacing="0" >
        <tr>
          <td width="13" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_13.jpg" width="13" height="22" alt="" /></td>
          <td height="22" align="right" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_14.jpg"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_15.jpg" width="142" height="22" alt="" /></td>
          <td width="4" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_16.jpg" width="4" height="22" alt="" /></td>
        </tr>
        <tr>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_24.jpg">&nbsp;</td>
          <td valign="top" bgcolor="#EAD9AE"><br />
              <?php if (mosCountModules('user4')>0) mosLoadModules('user4',0); ?>
              <?php if (mosCountModules('user2')>0) mosLoadModules('user2',0); ?>
          <?php if (mosCountModules('right')>0) mosLoadModules('right',0); ?></td>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_26.jpg">&nbsp;</td>
        </tr>
        <tr>
          <td width="13" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_35.jpg" width="13" height="9" alt="" /></td>
          <td height="9" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_36.jpg"></td>
          <td width="4" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_38.jpg" width="4" height="9" alt="" /></td>
        </tr>
    </table></td>
  </tr>
</table>
<table width="770" height="37" border="0" align="center" cellpadding="0" cellspacing="0">
  <tr>
    <td width="66"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_41.jpg" width="66" height="37" alt="" /></td>
    <td align="center" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_42.jpg">
	<?php if (mosCountModules('bottom')>0){mosLoadModules('bottom',0);} else {echo "&nbsp;";}?>
	</td>
    <td width="135" ><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_44.jpg" width="135" height="37" alt="" /></td>
  </tr>
</table>

<p>
  <?php mosLoadModules ( 'debug', -2); ?>
</p>
</body>
</html>

==> magic3_1.9.0_src.tar.gz: magic3/templates/browns/index.php <==
<?php
/**
* @Template ... :  Browns:  
* @Version: 1.8
* @Package: A Joomla 1.0.X template
* @Copyright: (C) 2006 by Rami Ben-Ami - http://www.lady-beetle.com/
* @License: GPL
**/

defined( '_VALID_MOS' ) or die( 'Direct Access to this location is not allowed.' );
$iso = explode( '=', _ISO ); echo '<?xml version="1.0" encoding="'. $iso[1] .'"?' .'>';
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; <?php echo _ISO; ?>" />
<?php mosShowHead(); ?>

<!-- CSS Joomla code here -->
<link href="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/css/template_css.css";?>" rel="stylesheet" type="text/css" media="all" />
<link rel="shortcut icon" href="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/favicon.ico"; ?>" />

</head>
<?php if ( $my->id ) { initEditor(); } ?>
<body>


<table width="770" height="90" border="0" align="center" cellpadding="0" cellspacing="0" >
  <tr>
    <td valign="top" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>header.jpg"><table width="100%" border="0" cellpadding="10" cellspacing="0" >
        <tr>
          <td width="110">&nbsp;</td>
          <td>&nbsp;<font class="site_name"><?php echo $mosConfig_sitename; ?></font></td>
          <td align="right"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>logo.gif" alt="" /></td>
          <td width="10">&nbsp;</td>
        </tr>
    </table></td>
  </tr>
</table>
<table width="770" height="34" border="0" align="center" cellpadding="0" cellspacing="0" >
  <tr>
    <td width="488"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>header_02.jpg" width="488" height="34" alt="" /></td>
    <td align="right" valign="middle" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>head_06.jpg" bgcolor="#E0E0A0"><?php echo mosCurrentDate(); ?></td>
    <td width="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>head_08.jpg" width="9" height="34" alt="" /></td>
  </tr>
</table>
<table width="770" height="31" border="0" align="center" cellpadding="0" cellspacing="0" >
  <tr>
    <td width="131"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>header_09.jpg" width="131" height="31" alt="" /></td>
    <td bgcolor="#664301">&nbsp;<?php mosPathWay(); ?>
</td>
  </tr>
</table>
<table width="770" height="31" border="0" align="center" cellpadding="0" cellspacing="0" >
  <tr>
    <td width="162" valign="top"><table width="100%" height="100%" border="0" align="center" cellpadding="0" cellspacing="0" >
        <tr>
          <td width="13" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_13.jpg" width="13" height="22" alt="" /></td>
          <td height="22" align="right" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_14.jpg"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_15.jpg" width="142" height="22" alt="" /></td>
          <td width="4" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_16.jpg" width="4" height="22" alt="" /></td>
        </tr>
        <tr>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_24.jpg">&nbsp;</td>
          <td valign="top" bgcolor="#EAD9AE">&nbsp;<br />
              <?php if (mosCountModules('left')>0) mosLoadModules('left',0); ?>
          <?php if (mosCountModules('user1')>0) mosLoadModules('user1',0); ?></td>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_26.jpg">&nbsp;</td>
        </tr>
        <tr>
          <td width="13" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_35.jpg" width="13" height="9" alt="" /></td>
          <td height="9" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_36.jpg"></td>
          <td width="4" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_38.jpg" width="4" height="9" alt="" /></td>
        </tr>
    </table></td>
    <td width="5" bgcolor="#664301">&nbsp;</td>
    <td valign="top"><table width="100%" height="100%" border="0" align="center" cellpadding="0" cellspacing="0" >
        <tr>
          <td width="13" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_13.jpg" width="13" height="22" alt="" /></td>
          <td height="22" align="right" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_14.jpg">&nbsp;</td>
          <td width="4" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_16.jpg" width="4" height="22" alt="" /></td>
        </tr>
        <tr>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_24.jpg">&nbsp;</td>
          <td valign="top" bgcolor="#EAD9AE"><?php if (mosCountModules('user3')>0) mosLoadModules('user3',0); ?>
            <?php if (mosCountModules('top')>0) mosLoadModules('top',0); ?>
              <br />
              <hr />
          <?php mosMainBody(); ?>

</td>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_26.jpg">&nbsp;</td>
        </tr>
        <tr>
          <td width="13" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_35.jpg" width="13" height="9" alt="" /></td>
          <td height="9" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_36.jpg"></td>
          <td width="4" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_38.jpg" width="4" height="9" alt="" /></td>
        </tr>
    </table>
    </td>
    <td width="5" bgcolor="#664301">&nbsp;</td>
    <td width="162" valign="top"><table width="100%" height="100%" border="0" align="center" cellpadding="0" cellspacing="0" >
        <tr>
          <td width="13" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_13.jpg" width="13" height="22" alt="" /></td>
          <td height="22" align="right" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_14.jpg"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_15.jpg" width="142" height="22" alt="" /></td>
          <td width="4" height="22"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_16.jpg" width="4" height="22" alt="" /></td>
        </tr>
        <tr>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_24.jpg">&nbsp;</td>
          <td valign="top" bgcolor="#EAD9AE"><br />
              <?php if (mosCountModules('user4')>0) mosLoadModules('user4',0); ?>
              <?php if (mosCountModules('user2')>0) mosLoadModules('user2',0); ?>
          <?php if (mosCountModules('right')>0) mosLoadModules('right',0); ?></td>
          <td background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_26.jpg">&nbsp;</td>
        </tr>
        <tr>
          <td width="13" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_35.jpg" width="13" height="9" alt="" /></td>
          <td height="9" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_36.jpg"></td>
          <td width="4" height="9"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_38.jpg" width="4" height="9" alt="" /></td>
        </tr>
    </table></td>
  </tr>
</table>
<table width="770" height="37" border="0" align="center" cellpadding="0" cellspacing="0">
  <tr>
    <td width="66"><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_41.jpg" width="66" height="37" alt="" /></td>
    <td align="center" background="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_42.jpg">
	<?php if (mosCountModules('bottom')>0){mosLoadModules('bottom',0);} else {echo "&nbsp;";}?>
	</td>
    <td width="135" ><img src="<?php echo "$GLOBALS[mosConfig_live_site]/templates/$GLOBALS[cur_template]/images/"; ?>index_44.jpg" width="135" height="37" alt="" /></td>
  </tr>
</table>

<p>
  <?php mosLoadModules ( 'debug', -2); ?>
</p>
</body>
</html>
